from typing import Any, Optional

from gcs_cli.commands.storage_gateway._common import make_create_command
from gcs_cli.parsing import (
    globus_command,
    hpss_options,
    storage_gateway_create_and_update_params,
)
from gcs_cli.sdk_client.data import HPSSStoragePolicies, StorageGatewayDocument
from gcs_cli.services.gcs import HPSS_CONNECTOR_ID


@globus_command("hpss", short_help="Create a new HPSS storage gateway")
@storage_gateway_create_and_update_params(create=True)
@hpss_options(create=True)
@make_create_command
def hpss_create(
    *,
    authentication_mech: Optional[str],
    authenticator: Optional[str],
    uda_checksum: Optional[str],
    **kwargs: Any
) -> StorageGatewayDocument:
    """
    Create a new storage gateway. Requires a display name and a connector.
    Additional connector specific options may be required as well.
    """
    policies = HPSSStoragePolicies(
        authentication_mech=authentication_mech,
        authenticator=authenticator,
        uda_checksum=uda_checksum is not False,
    )

    return StorageGatewayDocument(
        connector_id=HPSS_CONNECTOR_ID, policies=policies, **kwargs
    )
