from typing import IO, Optional
from typing_extensions import TypedDict

from ..parsers import CalloutDict
from ..util import yaml, yaml_object


class UnsupportedCalloutConfigurationDict(TypedDict):
    callout: Optional[CalloutDict]


@yaml_object(yaml)
class UnsupportedCalloutConfiguration:
    def __init__(self, callout: Optional[CalloutDict] = None) -> None:
        self.callout: Optional[CalloutDict] = callout

    @property
    def is_myproxy(self) -> bool:
        return False

    @property
    def is_cilogon(self) -> bool:
        return False

    @property
    def is_gridmap(self) -> bool:
        return False

    def check(self, fp: Optional[IO] = None) -> int:
        if fp is not None:
            print(f"Unsupported callout: {self.callout}", file=fp)
        return 1

    def __eq__(self, other: object) -> bool:
        if not isinstance(other, UnsupportedCalloutConfiguration):
            return NotImplemented

        return self is other or self.__getstate__() == other.__getstate__()

    def __getstate__(self) -> UnsupportedCalloutConfigurationDict:
        return {
            "callout": self.callout,
        }

    def __setstate__(self, state: UnsupportedCalloutConfigurationDict) -> None:
        self.callout = state["callout"]
