from typing import Optional


class CephConfig:
    @staticmethod
    def __parse_bool(value: str) -> bool:
        return value.lower() in ["true", "yes", "on", "1"]

    def __init__(self, path: str = None) -> None:
        if path is None:
            path = "/etc/globus/globus-gridftp-server-ceph.conf"

        self.path = path
        self.host_name: Optional[str] = None
        self.mime_types_path: Optional[str] = None
        self.use_https = True
        self.use_virtual_host = False
        self.verify_peer = True
        self.ceph_rgw_admin_bucket: Optional[str] = "admin"
        self.ceph_rgw_admin_access_key_id: Optional[str] = None
        self.ceph_rgw_admin_secret_access_key: Optional[str] = None
        self.max_retries = 5
        self.retry_delay = 400

        with open(path, "r") as f:
            for line in f:
                line = line.split("#", 1)[0].strip()
                if line and "=" in line:
                    k, v = line.split("=", 1)
                    k = k.strip()
                    v = v.strip()
                    v = v.strip('"')

                    if k == "host_name":
                        self.host_name = v
                    elif k == "use_https":
                        self.use_https = self.__parse_bool(v)
                    elif k == "ceph_rgw_admin_access_key_id":
                        self.ceph_rgw_admin_access_key_id = v
                    elif k == "ceph_rgw_admin_secret_access_key":
                        self.ceph_rgw_admin_secret_access_key = v
                    elif k == "ceph_rgw_admin_bucket":
                        self.ceph_rgw_admin_bucket = v
                    elif k == "use_virtual_host":
                        self.use_virtual_host = self.__parse_bool(v)
                    elif k == "mime_types_path":
                        self.mime_types_path = v
                    elif k == "verify_peer":
                        self.verify_peer = self.__parse_bool(v)
                    elif k == "max_retries":
                        self.max_retries = int(v)
                    elif k == "retry_delay":
                        self.retry_delay = int(v)
                    else:
                        raise KeyError(f"Unsupported configuration key {k}")
