from .collection import Collection
from globus.manager.constants import ConfigurationObjectTag
import globus.manager.api.errors as errors


class S3Collection(Collection):
    POLICY_DATA_TYPE = "s3_collection_policies#1.0.0"
    POLICY_DATA_TYPES = [POLICY_DATA_TYPE]

    __mapper_args__ = {
        "polymorphic_identity": (
            ConfigurationObjectTag.COLLECTION.name
            + "7643e831-5f6c-4b47-a07f-8ee90f401d23"
        )
    }

    def check_user_credential(self, credential):
        payer_required = getattr(self.storage_gateway, "s3_requester_pays", False)
        payer_allowed = getattr(credential, "s3_requester_pays", False)
        if payer_required and not payer_allowed:
            credential.invalid = True
            raise errors.InvalidCredentialError(
                "The existing credential has not acknowledged requester pays.",
                user_credential_id=credential.id,
            )
        return True

    @property
    def connector_id(self):
        return "7643e831-5f6c-4b47-a07f-8ee90f401d23"

    @connector_id.setter
    def connector_id(self, value):
        pass

    def __repr__(self):
        return "<S3Collection {}>".format(self.id)
