from ..api.collection import CollectionSchema
from ..api.storage_gateway import StorageGatewaySchema
from ..api.user_credential import UserCredentialSchema
from .s3 import (
    S3StoragePolicies_1_0_0,
    S3UserCredentialPolicies_1_0_0,
    S3CollectionPolicies,
)


ACTIVESCALE_CONNECTOR_ID = "7251f6c8-93c9-11eb-95ba-12704e0d6a4d"


class ActiveScaleStoragePolicies(S3StoragePolicies_1_0_0):
    """
    Connector-specific storage gateway policies for the ActiveScale connector.
    These are identical to s3 connector's storage gateway policies.
    """

    connector_id = ACTIVESCALE_CONNECTOR_ID


class ActiveScaleCollectionPolicies(S3CollectionPolicies):
    """
    Connector-specific collection policies for the ActiveScale connector.
    These are identical to s3 connector's collection policies.
    """

    connector_id = ACTIVESCALE_CONNECTOR_ID


class ActiveScaleUserCredentialPolicies(S3UserCredentialPolicies_1_0_0):
    """
    Connector-specific user credential policies for the ActiveScale connector.
    These are identical to s3 connector's user credential policies.
    """

    connector_id = ACTIVESCALE_CONNECTOR_ID


activescale_storage_policies_schema = ActiveScaleStoragePolicies(
    load_only=ActiveScaleStoragePolicies.private
)
activescale_storage_policies_private_schema = ActiveScaleStoragePolicies()

activescale_user_credential_policies_private_schema = (
    ActiveScaleUserCredentialPolicies()
)
activescale_user_credential_policies_schema = ActiveScaleUserCredentialPolicies(
    load_only=ActiveScaleUserCredentialPolicies.private
)
activescale_collection_policies_schema = ActiveScaleCollectionPolicies(
    load_only=ActiveScaleCollectionPolicies.private
)
activescale_collection_policies_private_schema = ActiveScaleCollectionPolicies()

StorageGatewaySchema.register_schema(
    public=activescale_storage_policies_schema,
    private=activescale_storage_policies_private_schema,
)

UserCredentialSchema.register_schema(
    public=activescale_user_credential_policies_schema,
    private=activescale_user_credential_policies_private_schema,
)

CollectionSchema.register_schema(
    public=activescale_collection_policies_schema,
    private=activescale_collection_policies_private_schema,
)
