import json

import click
from jwcrypto import jwk

from gcs_cli.parsing.command_decorator import globus_command


class NodeKeyFileParam(click.File):
    name = "node_key_file"

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

    def convert(self, value, param, ctx):
        with super().convert(value, param, ctx) as f:
            try:
                node_key = jwk.JWK(**json.loads(f.read()))
            except Exception as e:
                self.fail("Error parsing {}: {}".format(value, str(e)), param, ctx)
        return node_key


@globus_command(
    "cleanup",
    short_help="Clean up a Globus Connect Server endpoint",
    help="Clean up a Globus Connect Server endpoint",
    disable_options=["format", "explicit_host"],
)
@click.option(
    "--client-id",
    "-c",
    help="Auth Client ID for this Globus Connect Server Endpoint",
    required=True,
)
@click.option(  # type: ignore # hidden/required
    "--secret",
    "-s",
    help="Secret for the auth client",
    required=True,
    hidden=True,
    prompt=True,
    hide_input=True,
)
@click.option(
    "--deployment-key",
    help="Path to deployment key",
    type=NodeKeyFileParam(),
)
@click.option(
    "--development-appsync",
    help="Use the specified URL and client_id for the appsync service",
    metavar="APPSYNC_URL APPSYNC_CLIENT_ID",
    nargs=2,
    hidden=True,
)
@click.pass_context
def endpoint_cleanup(ctx, client_id, secret, deployment_key, development_appsync):
    from .endpoint_cleanup import endpoint_cleanup as ec

    ec(ctx, client_id, secret, deployment_key, development_appsync)
