"""Remove unencrypted credential and policy

Revision ID: 75642f3dcaf3
Revises: b85b3712bcd9
Create Date: 2019-12-21 14:04:36.781218

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '75642f3dcaf3'
down_revision = 'b85b3712bcd9'
branch_labels = None
depends_on = None


def upgrade():
    op.execute('PRAGMA foreign_keys = OFF')
    op.execute("PRAGMA legacy_alter_table = ON")

    # Remove the deleted column from storage_gateway, as it is redundant with
    # the configuration_object table
    op.rename_table('user_credential', 'user_credential_old')
    op.create_table(
	'user_credential',
	sa.Column('id',
	    sa.TEXT(),
	    nullable=False),
	sa.Column(
	    'display_name',
	    sa.TEXT(),
	    nullable=True),
	sa.Column(
	    'identity_id',
	    sa.TEXT(),
	    nullable=False),
	sa.Column(
	    'username',
	    sa.TEXT(),
	    nullable=False),
	sa.Column(
	    'invalid',
	    sa.Boolean(),
	    server_default='0',
	    nullable=False),
	sa.Column(
	    'storage_gateway_id',
	    sa.TEXT(),
	    nullable=False),
	sa.ForeignKeyConstraint(
	    ['id'],
	    ['configuration_object.id'], ),
	sa.ForeignKeyConstraint(
	    ['storage_gateway_id'],
	    ['storage_gateway.id'], ),
	sa.PrimaryKeyConstraint('id'),
	sa.UniqueConstraint(
	    'storage_gateway_id',
	    'username',
	    'identity_id')
    )
    op.execute(
	"""
	INSERT INTO user_credential (
	    id, display_name, identity_id,
	    username,
	    invalid, storage_gateway_id)
	SELECT id, display_name, identity_id,
	    storage_gateway_user_id,
	    invalid, storage_gateway_id
	FROM user_credential_old
	""")
    op.drop_table("user_credential_old")

    # Remove storage_policies and credential columns
    op.rename_table("storage_gateway", "storage_gateway_old")
    op.create_table(
        'storage_gateway',
        sa.Column('id', sa.TEXT(),
            nullable=False),
        sa.Column(
            'display_name',
            sa.TEXT(),
            nullable=False),
        sa.Column(
            'allow_guest_collections',
            sa.BOOLEAN(),
            server_default='0',
            nullable=False),
        sa.Column(
            'allow_mapped_collections',
            sa.BOOLEAN(),
            server_default='0',
            nullable=False),
        sa.Column(
            'require_high_assurance',
            sa.BOOLEAN(),
            server_default='0',
            nullable=False),
        sa.Column(
            'connector_id',
            sa.TEXT(),
            nullable=False),
        sa.ForeignKeyConstraint(
            ['id'],
            ['configuration_object.id'],),
        sa.PrimaryKeyConstraint('id'),
        sa.UniqueConstraint('display_name')
    )
    op.execute(
        """
        INSERT INTO storage_gateway
        (id, display_name, allow_guest_collections, allow_mapped_collections,
        require_high_assurance, connector_id)
        SELECT id, display_name, allow_guest_collections, allow_mapped_collections,
        require_high_assurance, connector_id
        FROM storage_gateway_old
        """)
    # Remove the backup
    op.drop_table('storage_gateway_old')


def downgrade():
    raise RuntimeError("downgrade migration not implemented")
